@@ -15,16 +15,16 @@ import os # delete
 
 # Additional Resources
 
-from resources.commands_list import cmdList
-from system_parser.tokens import tokens
-from system_parser.tokens_definition import *
+import junipercs.resources.commands_list as cmd_list_file 
+import junipercs.system_parser.tokens as tokens_file
+import junipercs.system_parser.tokens_definition 
 
 # Commands
 
-import modules.options as options
-import modules.create as create
-import modules.goto as goto
-import modules.list as list_cmd
+import junipercs.modules.options as options
+import junipercs.modules.create as create
+import junipercs.modules.goto as goto
+import junipercs.modules.list as list_cmd
 
 #-------------------------------------------
 # ___________GLOBAL VARIABLES_______________
@@ -34,6 +34,14 @@ import modules.list as list_cmd
 
 varMemory = {}
 
+# Commands List
+
+cmdList = cmd_list_file.cmdList
+
+# System Tokens
+
+tokens = tokens_file.tokens
+
 # Auxiliary Checks
 
 checkString = False
